import requests

def rGET(url, headers={}, cookies={}, timeout=30, retry=5, chromeHeader=True):
    if chromeHeader == True:
        headers['User-Agent'] = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.82 Safari/537.36'
    for i in range(retry):
        try:
            result = requests.get(url, headers=headers, cookies=cookies, timeout=timeout)
            return result
        except:
            print(F'Get failed, retry {i+1}/{retry}')
    print('Get failed')

def rPOST(url, data, headers={}, cookies={}, timeout=30, retry=5, chromeHeader=True):
    if chromeHeader == True:
        headers['User-Agent'] = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.82 Safari/537.36'
    for i in range(retry):
        try:
            result = requests.post(url, data=data, headers=headers, cookies=cookies, timeout=timeout)
            return result
        except:
            print(F'Post failed, retry {i+1}/{retry}')
    print('Post failed')



import os



def find(path, itemType='a'):
    """
    Return folders and/or files in a given path.

    Arguments:
        path (str)

    Keyword Arguments:
        itemType (str)
            'd': dir
            'f': file
            'a': dir & file [default]

    Returns:
        list
    """
    result = []
    if itemType == 'a':
        for itemName in os.listdir(path):
            itemPath = path + '/' + itemName
            result.append(itemPath)
    elif itemType == 'd':
        for itemName in os.listdir(path):
            itemPath = path + '/' + itemName
            if os.path.isdir(itemPath):
                result.append(itemPath)
    elif itemType == 'f':
        for itemName in os.listdir(path):
            itemPath = path + '/' + itemName
            if os.path.isfile(itemPath):
                result.append(itemPath)
    return result


def findall(path, fileExts=[]):
    """
    Return all files in a given path recursively.

    Arguments:
        path (str)

    Keyword Arguments:
        fileExts (list)
            e.g.:
                ['exe', 'jpg']
                ['ini']
            []: matches all files [default]

    Returns:
        list
    """
    result = []
    if fileExts == []:
        for root, _, files in os.walk(path):
            for i in files:
                result.append(root.replace('\\','/') + '/' + i)
    else:
        for root, _, files in os.walk(path):
            for i in files:
                if os.path.splitext(i.lower())[-1][1:] in fileExts:
                    result.append(root.replace('\\','/') + '/' + i)
    return result



def resize(orig, limitation, upscale=False):
    """
    Return resized resolution.

    Arguments:
        orig: (w, h)
        limitation: (w, h)

    Keyword Arguments:
        upscale: Bool
            True: upscale if orig < limitation
            False: not upscale [default]

    Returns:
        (w, h)
    """
    Orig_w = orig[0]
    Orig_h = orig[1]
    Lmt_w = limitation[0]
    Lmt_h = limitation[1]

    if Lmt_w == 0:
        if Orig_h < Lmt_h and upscale == False:
            return (Orig_w, Orig_h)
        else:
            return (Orig_w*(Lmt_h/Orig_h), Lmt_h)
    elif Lmt_h == 0:
        if Orig_w < Lmt_w and upscale == False:
            return (Orig_w, Orig_h)
        else:
            return (Lmt_w, Orig_h*(Lmt_w/Orig_w))
    else:
        if Orig_w/Orig_h > Lmt_w/Lmt_h:
            if Orig_w < Lmt_w and upscale == False:
                return (Orig_w, Orig_h)
            else:
                return (Lmt_w, Orig_h*(Lmt_w/Orig_w))
        elif Orig_w/Orig_h < Lmt_w/Lmt_h:
            if Orig_h < Lmt_h and upscale == False:
                return (Orig_w, Orig_h)
            else:
                return (Orig_w*(Lmt_h/Orig_h), Lmt_h)
        else:
            if Orig_w < Lmt_w and upscale == False:
                return (Orig_w, Orig_h)
            else:
                return (Lmt_w, Lmt_h)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="azunyan",
    version="2.0.2",
    author="Elypha",
    author_email="i@elypha.com",
    description="Some simple functions I packed for self usage",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Elypha/azunyan",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)

## upgrade
# python3 -m pip install --user --upgrade setuptools wheel twine
## pack
# python3 setup.py sdist bdist_wheel
## upload
# python3 -m twine upload dist/*
## clean
# rm azunyan.egg-info build dist
## upgrade
# python3 -m pip install --upgrade azunyan -i https://pypi.org/simple/
